# -*- coding: utf-8 -*-
from mod_python import apache
from os.path import dirname
from lxml import etree
import re


def getLanguages( dataFile ):

	languages = []

	lFragments = dataFile.xpath( '/eb:data/eb:languages/eb:language' ,
			namespaces = { 'eb': 'http://www.ebenoit.info/data' } )

	for node in lFragments:
		languages.append( node.get( 'id' ) )

	return languages


def guessLanguage( acceptString , languages ):
	acceptString = re.sub( r'[^a-zA-Z0-9\.\-;,=]' , '' , acceptString )
	if len( acceptString ) == 0:
		return languages[ 0 ]

	# Build a list using the different weights as keys
	accepted = { }
	aList = acceptString.split( ',' )

	for lString in aList:

		if lString == '':
			continue

		lData = lString.split( ';q=' )
		if len( lData ) == 1:
			lData.append( '1.0' )

		lStr = lData[ 0 ]
		lWeight = float( lData[ 1 ] ) * 1000

		if lWeight in accepted:
			accepted[ lWeight ].append( lStr )
		else:
			accepted[ lWeight ] = [ lStr ]

	# Iterate for all languages in the weight-specific order
	weights = accepted.keys( );
	weights.sort( );
	for lWeight in reversed( weights ) :
		for lStr in accepted[ lWeight ]:
			if lStr in languages:
				return lStr

	return languages[ 0 ]


def handler( req ):

	# Find the script's base URI and physical path
	sPath = req.parsed_uri[ apache.URI_PATH ]
	if sPath.find( 'index.py' ) == -1:
		sPath = sPath + 'index.py'
	if req.path_info:
		sPath = sPath[ 0 : -len( req.path_info ) ]
	basePath = dirname( sPath )
	if basePath[ len( basePath ) - 1 ] != '/' :
		basePath = basePath + '/'
	dataPath = dirname( req.finfo[apache.FINFO_FNAME] ) + '/data/'

	# Extract requested language and page from the path
	lang = ""
	page = "main"
	if req.path_info:
		splitPath = req.path_info[ 1 : ].split( '/' )
		if len( splitPath ) == 1:
			page = splitPath.pop(0)
		elif len( splitPath ) >= 2:
			lang = splitPath.pop(0)
			page = splitPath.pop(0)

	# Check if the page name is valid
	vPageExp = re.compile( '^[a-z]+$' , re.IGNORECASE )
	if not vPageExp.match( page ):
		page = "main"

	# Read the data file
	dataFile = etree.parse( dataPath + 'data.xml' )

	# Find out which languages are supported
	languages = getLanguages( dataFile )

	# Check if the selected language is valid
	if lang != '' and lang not in languages:
		lang = ''

	# If there is no specified language, try to guess it
	# according to Accept-Language
	if lang == '':
		if req.headers_in.has_key( 'Accept-Language' ):
			acceptString = req.headers_in[ 'Accept-Language' ]
			lang = guessLanguage( acceptString , languages )
		else:
			lang = languages[ 0 ]

	# Load the XSLT stylesheet
	transform = etree.XSLT( etree.parse( dataPath + 'site.xsl' ) )

	# Check if the client accepts application/xhtml+xml
	if req.headers_in.has_key( 'Accept' ):
		accept = re.split( '[;,]' , req.headers_in[ 'Accept' ].lower() )
		if 'application/xhtml+xml' in accept:
			req.content_type = 'application/xhtml+xml'
		else:
			req.content_type = 'text/html'
	else:
		req.content_type = 'text/html'

	req.write( str( transform( dataFile ,
			reqPage = "'" + page + "'" ,
			reqLang = "'" + lang + "'" ,
			cssPath = "'" + basePath + "'" ,
			scriptPath = "'" + sPath + "'" ) ) )

	return apache.OK
